@@ -45,7 +45,12 @@ except Exception as e:
     print(f'jellex: There was a problem opening that file:\n        {e}', file=sys.stderr)
     sys.exit(1)
 
-jdata = load_json(file_text)
+try:
+    jdata = load_json(file_text)
+except JSONDecodeError:
+    print('jellex: That was not a JSON or JSON Lines file.', file=sys.stderr)
+    sys.exit(1)
+
 del file_text
 json_out = Json()
 schema_out = Schema()
@@ -76,7 +81,7 @@ def get_item_stats(item):
 
 
 def get_json(query):
-    """Returns a Tuple of (<JSON Response>, <Stats|Exception Message>)"""
+    """Updates response, last_output, and status_text"""
     global last_output
     global status_text
     global response
@@ -89,10 +94,6 @@ def get_json(query):
         last_output = output[:10000]
         status_text = get_item_stats(response)
 
-    except JSONDecodeError:
-        print('jellex: That was not a JSON file.', file=sys.stderr)
-        sys.exit(1)
-
     except Exception as e:
         exception_name = e.__class__.__name__.replace('<', '').replace('>', '')
         exception_message = str(e).replace('<', '').replace('>', '')
@@ -100,7 +101,7 @@ def get_json(query):
 
 
 def get_schema():
-    """Returns schema output from jello"""
+    """Updates last_schema_output"""
     global last_schema_output
     global response
 
